@@ -247,14 +247,14 @@ BlameDisplay_impl::BlameDisplay_impl(TQWidget*parent,const char*name)
     : BlameDisplay(parent,name)
 {
     m_Data = new BlameDisplayData();
-    connect(m_BlameList,TQT_SIGNAL(selectionChanged()),this,TQT_SLOT(slotSelectionChanged()));
+    connect(m_BlameList,TQ_SIGNAL(selectionChanged()),this,TQ_SLOT(slotSelectionChanged()));
 }
 
 BlameDisplay_impl::BlameDisplay_impl(const TQString&what,const svn::AnnotatedFile&blame,TQWidget*parent,const char*name)
     : BlameDisplay(parent,name)
 {
     m_Data = new BlameDisplayData();
-    connect(m_BlameList,TQT_SIGNAL(selectionChanged()),this,TQT_SLOT(slotSelectionChanged()));
+    connect(m_BlameList,TQ_SIGNAL(selectionChanged()),this,TQ_SLOT(slotSelectionChanged()));
     setContent(what,blame);
 }
 
@@ -268,8 +268,8 @@ void BlameDisplay_impl::setContent(const TQString&what,const svn::AnnotatedFile&
     m_Data->m_File = what;
     m_SearchWidget = new TDEListViewSearchLineWidget(m_BlameList,this);
     EncodingSelector_impl*m_Ls = new EncodingSelector_impl(Kdesvnsettings::locale_for_blame(),this);
-    connect(m_Ls,TQT_SIGNAL(TextCodecChanged(const TQString&)),
-            this,TQT_SLOT(slotTextCodecChanged(const TQString&)));
+    connect(m_Ls,TQ_SIGNAL(TextCodecChanged(const TQString&)),
+            this,TQ_SLOT(slotTextCodecChanged(const TQString&)));
 
     BlameDisplayLayout->remove(m_BlameList);
     BlameDisplayLayout->addWidget(m_Ls);
@@ -410,7 +410,7 @@ void BlameDisplay_impl::showCommit(BlameDisplayItem*bit)
         }
     }
     KDialogBase* dlg = new KDialogBase(
-            TQT_TQWIDGET(TDEApplication::activeModalWidget()),
+            TDEApplication::activeModalWidget(),
     "simplelog",true,TQString(i18n("Logmessage for revision %1").arg(bit->rev())),
     KDialogBase::Close);
     TQWidget* Dialog1Layout = dlg->makeVBoxMainWidget();
@@ -446,7 +446,7 @@ void BlameDisplay_impl::displayBlame(SimpleLogCb*_cb,const TQString&item,const s
 {
     int buttons = KDialogBase::Close|KDialogBase::User1|KDialogBase::User2;
     KDialogBase * dlg = new KDialogBase(
-            TQT_TQWIDGET(TDEApplication::activeModalWidget()),
+            TDEApplication::activeModalWidget(),
             name,true,TQString(i18n("Blame %1")).arg(item),buttons,KDialogBase::Close,false,
             KGuiItem(i18n("Goto line")),KGuiItem(i18n("Log message for revision"),"tdesvnlog"));
 
@@ -457,8 +457,8 @@ void BlameDisplay_impl::displayBlame(SimpleLogCb*_cb,const TQString&item,const s
     ptr->setCb(_cb);
     ptr->m_Data->m_dlg = dlg;
     dlg->enableButton(KDialogBase::User2,false);
-    connect(dlg,TQT_SIGNAL(user1Clicked()),ptr,TQT_SLOT(slotGoLine()));
-    connect(dlg,TQT_SIGNAL(user2Clicked()),ptr,TQT_SLOT(slotShowCurrentCommit()));
+    connect(dlg,TQ_SIGNAL(user1Clicked()),ptr,TQ_SLOT(slotGoLine()));
+    connect(dlg,TQ_SIGNAL(user2Clicked()),ptr,TQ_SLOT(slotShowCurrentCommit()));
     Dialog1Layout->adjustSize();
     dlg->exec();
 
