@@ -92,12 +92,12 @@ RevGraphView::RevGraphView(TQObject*aListener,svn::Client*_client,TQWidget * par
     m_CompleteView->setHScrollBarMode(TQScrollView::AlwaysOff);
     m_CompleteView->raise();
     m_CompleteView->hide();
-    connect(this, TQT_SIGNAL(contentsMoving(int,int)),
-            this, TQT_SLOT(contentsMovingSlot(int,int)));
-    connect(m_CompleteView, TQT_SIGNAL(zoomRectMoved(int,int)),
-            this, TQT_SLOT(zoomRectMoved(int,int)));
-    connect(m_CompleteView, TQT_SIGNAL(zoomRectMoveFinished()),
-            this, TQT_SLOT(zoomRectMoveFinished()));
+    connect(this, TQ_SIGNAL(contentsMoving(int,int)),
+            this, TQ_SLOT(contentsMovingSlot(int,int)));
+    connect(m_CompleteView, TQ_SIGNAL(zoomRectMoved(int,int)),
+            this, TQ_SLOT(zoomRectMoved(int,int)));
+    connect(m_CompleteView, TQ_SIGNAL(zoomRectMoveFinished()),
+            this, TQ_SLOT(zoomRectMoveFinished()));
     m_LastAutoPosition = TopLeft;
     _isMoving = false;
     _noUpdateZoomerPos = false;
@@ -495,9 +495,9 @@ void RevGraphView::dumpRevtree()
     renderProcess->setEnvironment("LANG","C");
     *renderProcess << "dot";
     *renderProcess << dotTmpFile->name() << "-Tplain";
-    connect(renderProcess,TQT_SIGNAL(processExited(TDEProcess*)),this,TQT_SLOT(dotExit(TDEProcess*)));
-    connect(renderProcess,TQT_SIGNAL(receivedStdout(TDEProcess*,char*,int)),
-        this,TQT_SLOT(readDotOutput(TDEProcess*,char*,int)) );
+    connect(renderProcess,TQ_SIGNAL(processExited(TDEProcess*)),this,TQ_SLOT(dotExit(TDEProcess*)));
+    connect(renderProcess,TQ_SIGNAL(receivedStdout(TDEProcess*,char*,int)),
+        this,TQ_SLOT(readDotOutput(TDEProcess*,char*,int)) );
     if (!renderProcess->start(TDEProcess::NotifyOnExit,TDEProcess::Stdout)) {
         TQString arguments;
         for (unsigned c=0;c<renderProcess->args().count();++c) {
@@ -735,7 +735,7 @@ void RevGraphView::makeSelected(GraphTreeLabel*gtl)
 void RevGraphView::contentsMouseDoubleClickEvent ( TQMouseEvent * e )
 {
     setFocus();
-    if (e->button() == Qt::LeftButton) {
+    if (e->button() == TQt::LeftButton) {
         TQCanvasItemList l = canvas()->collisions(e->pos());
         if (l.count()>0) {
             TQCanvasItem* i = l.first();
@@ -901,7 +901,7 @@ void RevGraphView::makeCat(GraphTreeLabel*_l)
     }
     svn::Revision tr(it.data().rev);
     TQString tp = _basePath+it.data().name;
-    emit makeCat(tr,tp,it.data().name,tr,TQT_TQWIDGET(kapp->activeModalWidget()));
+    emit makeCat(tr,tp,it.data().name,tr,kapp->activeModalWidget());
 }
 
 void RevGraphView::makeDiffPrev(GraphTreeLabel*_l)
@@ -931,9 +931,9 @@ void RevGraphView::makeDiff(const TQString&n1,const TQString&n2)
     svn::Revision tr(it.data().rev);
     TQString tp = _basePath+it.data().name;
     if (Kdesvnsettings::tree_diff_rec()) {
-        emit makeRecDiff(sp,sr,tp,tr,TQT_TQWIDGET(kapp->activeModalWidget()));
+        emit makeRecDiff(sp,sr,tp,tr,kapp->activeModalWidget());
     } else {
-        emit makeNorecDiff(sp,sr,tp,tr,TQT_TQWIDGET(kapp->activeModalWidget()));
+        emit makeNorecDiff(sp,sr,tp,tr,kapp->activeModalWidget());
     }
 }
 
@@ -944,7 +944,7 @@ void RevGraphView::setBasePath(const TQString&_path)
 
 void RevGraphView::slotClientException(const TQString&what)
 {
-    KMessageBox::sorry(TQT_TQWIDGET(TDEApplication::activeModalWidget()),what,i18n("SVN Error"));
+    KMessageBox::sorry(TDEApplication::activeModalWidget(),what,i18n("SVN Error"));
 }
 
 #include "revgraphview.moc"
