@@ -580,7 +580,7 @@ void SvnLogDlgImp::slotBlameItem()
         return;
     }
     svn::Revision start(svn::Revision::START);
-    m_Actions->makeBlame(start,k->rev(),_base+k->realName(),TQT_TQWIDGET(kapp->activeModalWidget()),k->rev(),this);
+    m_Actions->makeBlame(start,k->rev(),_base+k->realName(),kapp->activeModalWidget(),k->rev(),this);
 }
 
 void SvnLogDlgImp::slotEntriesSelectionChanged()
@@ -618,7 +618,7 @@ void SvnLogDlgImp::slotSingleContext(TQListViewItem*_item, const TQPoint & e, in
     {
         case 101:
         {
-            m_Actions->makeBlame(start,k->rev(),_base+name,TQT_TQWIDGET(kapp->activeModalWidget()),k->rev(),this);
+            m_Actions->makeBlame(start,k->rev(),_base+name,kapp->activeModalWidget(),k->rev(),this);
             break;
         }
         case 102:
@@ -628,7 +628,7 @@ void SvnLogDlgImp::slotSingleContext(TQListViewItem*_item, const TQPoint & e, in
         }
         case 103:
         {
-            emit makeCat(k->rev(),_base+source,source,k->rev(),TQT_TQWIDGET(kapp->activeModalWidget()));
+            emit makeCat(k->rev(),_base+source,source,k->rev(),kapp->activeModalWidget());
         }
         default:
             break;
@@ -654,7 +654,7 @@ void SvnLogDlgImp::slotSingleDoubleClicked(TQListViewItem*_item)
     //svn_revnum_t prev = item->revision()>0?item->revision():k->rev()-1;
     svn::Revision start(svn::Revision::START);
     if (action != "D") {
-        m_Actions->makeBlame(start,k->rev(),_base+name,TQT_TQWIDGET(kapp->activeModalWidget()),k->rev(),this);
+        m_Actions->makeBlame(start,k->rev(),_base+name,kapp->activeModalWidget(),k->rev(),this);
     }
 }
 
