@@ -1,5 +1,5 @@
 /*
- * Port for usage with qt-framework and development for tdesvn
+ * Port for usage with tqt-framework and development for tdesvn
  * (C) 2005-2007 by Rajko Albrecht
  * http://tdesvn.alwins-world.de
  */
@@ -126,7 +126,7 @@ namespace svn
             const Revision revision = svn::Revision::HEAD,
             bool detailed_remote = false,
             bool hide_externals = false,
-            const StringArray & changelists=StringArray()) throw (ClientException);
+            const StringArray & changelists=StringArray());
 
     /**
      * Returns the status of a single file in the path.
@@ -139,7 +139,7 @@ namespace svn
      * @return a Status with Statis.isVersioned = FALSE
      */
     virtual StatusPtr
-    singleStatus (const Path& path,bool update=false,const Revision revision = svn::Revision::HEAD) throw (ClientException);
+    singleStatus (const Path& path,bool update=false,const Revision revision = svn::Revision::HEAD);
 
   /**
      * Executes a revision checkout.
@@ -159,7 +159,7 @@ namespace svn
               svn::Depth depth=DepthInfinity,
               bool ignore_externals=false,
               bool overwrite=false
-             ) throw (ClientException);
+             );
 
     /**
      * relocate wc @a from to @a to
@@ -167,7 +167,7 @@ namespace svn
      */
     virtual void
     relocate (const Path & path, const TQString &from_url,
-              const TQString &to_url, bool recurse) throw (ClientException);
+              const TQString &to_url, bool recurse);
 
     /**
      * Sets a single file for deletion.
@@ -176,7 +176,7 @@ namespace svn
     virtual svn::Revision
             remove (const Path & path, bool force,
                     bool keep_local = true,
-                    const PropertiesMap&revProps = PropertiesMap()) throw (ClientException);
+                    const PropertiesMap&revProps = PropertiesMap());
 
     /**
      * Sets files for deletion.
@@ -189,7 +189,7 @@ namespace svn
     remove (const Targets & targets,
             bool force,
             bool keep_local = true,
-            const PropertiesMap&revProps = PropertiesMap()) throw (ClientException);
+            const PropertiesMap&revProps = PropertiesMap());
 
     /**
      * Reverts a couple of files to a pristiner state.
@@ -199,7 +199,7 @@ namespace svn
             revert (const Targets & targets,
                     Depth depth,
                     const StringArray&changelist=StringArray()
-                   ) throw (ClientException);
+                   );
 
 
     /**
@@ -212,7 +212,7 @@ namespace svn
      * @exception ClientException
      * @sa svn::Depth
      */
-    virtual void add (const Path & path, svn::Depth depth,bool force=false, bool no_ignore=false, bool add_parents = true) throw (ClientException);
+    virtual void add (const Path & path, svn::Depth depth,bool force=false, bool no_ignore=false, bool add_parents = true);
 
     /**
      * Updates the file or directory.
@@ -228,7 +228,7 @@ namespace svn
     virtual Revisions
     update (const Targets & path, const Revision & revision,
             Depth depth,bool ignore_externals,bool allow_unversioned,
-            bool sticky_depth) throw (ClientException);
+            bool sticky_depth);
 
     /**
      * Retrieves the contents for a specific @a revision of
@@ -243,7 +243,7 @@ namespace svn
     virtual TQByteArray
     cat (const Path & path,
           const Revision & revision,
-          const Revision & peg_revision=svn_opt_revision_unspecified) throw (ClientException);
+          const Revision & peg_revision=svn_opt_revision_unspecified);
     /**
      * Retrieves the contents for a specific @a revision of
      * a @a path at @a peg_revision
@@ -258,7 +258,7 @@ namespace svn
     cat(svn::stream::SvnStream&buffer,
             const Path & path,
             const Revision & revision,
-            const Revision & peg_revision) throw (ClientException);
+            const Revision & peg_revision);
 
     /**
      * Retrieves the contents for a specific @a revision of
@@ -274,7 +274,7 @@ namespace svn
     get (const Path & path,
           const TQString  & target,
           const Revision & revision,
-          const Revision & peg_revision=svn_opt_revision_unspecified) throw (ClientException);
+          const Revision & peg_revision=svn_opt_revision_unspecified);
 
     /**
      * Retrieves the contents for a specific @a revision of
@@ -295,7 +295,7 @@ namespace svn
               const DiffOptions&diffoptions = DiffOptions(),
               bool ignore_mimetypes = false,
               bool include_merged_revisions = false
-             ) throw (ClientException);
+             );
 
     /**
      * Commits changes to the repository. This usually requires
@@ -316,7 +316,7 @@ namespace svn
             const svn::StringArray&changelist=svn::StringArray(),
             const PropertiesMap&revProps=PropertiesMap(),
             bool keep_changelist=false
-           ) throw (ClientException);
+           );
 
     /**
      * Copies a versioned file with the history preserved.
@@ -325,7 +325,7 @@ namespace svn
     virtual svn::Revision
     copy (const Path & srcPath,
           const Revision & srcRevision,
-          const Path & destPath) throw (ClientException);
+          const Path & destPath);
     /**
      * Copies a versioned file with the history preserved.
      * @since subversion 1.5 api
@@ -337,7 +337,7 @@ namespace svn
           const Revision & srcRevision,
           const Revision & pegRevision,
           const Path & destPath,
-          bool asChild=false,bool makeParent=false,const PropertiesMap&revProps=PropertiesMap()) throw (ClientException);
+          bool asChild=false,bool makeParent=false,const PropertiesMap&revProps=PropertiesMap());
 
     /**
      * Moves or renames a file.
@@ -346,7 +346,7 @@ namespace svn
     virtual svn::Revision
     move (const Path & srcPath,
           const Path & destPath,
-          bool force) throw (ClientException);
+          bool force);
 
     /**
      * Moves or renames a file.
@@ -355,7 +355,7 @@ namespace svn
     virtual svn::Revision
             move (const Targets & srcPath,
                   const Path & destPath,
-                  bool force,bool asChild,bool makeParent,const PropertiesMap&revProps=PropertiesMap()) throw (ClientException);
+                  bool force,bool asChild,bool makeParent,const PropertiesMap&revProps=PropertiesMap());
 
     /**
      * Creates a directory directly in a repository or creates a
@@ -372,7 +372,7 @@ namespace svn
            const TQString& message,
            bool makeParent=true,
            const PropertiesMap&revProps=PropertiesMap()
-          ) throw (ClientException);
+          );
     /**
      * Creates a directory directly in a repository or creates a
      * directory on disk and schedules it for addition. If <i>path</i>
@@ -388,7 +388,7 @@ namespace svn
            const TQString& message,
            bool makeParent=true,
            const PropertiesMap&revProps=PropertiesMap()
-          ) throw (ClientException);
+          );
 
     /**
      * Recursively cleans up a local directory, finishing any
@@ -397,13 +397,13 @@ namespace svn
      * @exception ClientException
      */
     virtual void
-    cleanup (const Path & path) throw (ClientException);
+    cleanup (const Path & path);
 
     /**
      * Removes the 'conflicted' state on a file.
      * @exception ClientException
      */
-    virtual void resolve (const Path & path,Depth depth,const ConflictResult&resolution=ConflictResult()) throw (ClientException);
+    virtual void resolve (const Path & path,Depth depth,const ConflictResult&resolution=ConflictResult());
 
     /**
      * Exports the contents of either a subversion repository into a
@@ -428,7 +428,7 @@ namespace svn
               const TQString&native_eol=TQString(),
               bool ignore_externals = false,
               svn::Depth depth=svn::DepthInfinity
-             ) throw (ClientException);
+             );
 
     /**
      * Update local copy to mirror a new url. This excapsulates the
@@ -444,7 +444,7 @@ namespace svn
               bool sticky_depth = true,
               bool ignore_externals=false,
               bool allow_unversioned=false
-             ) throw (ClientException);
+             );
 
     /**
      * Import file or directory PATH into repository directory URL at
@@ -462,7 +462,7 @@ namespace svn
                     const TQString& message,
                     svn::Depth depth,
                     bool no_ignore,bool no_unknown_nodetype,
-                    const PropertiesMap&revProps=PropertiesMap()) throw (ClientException);
+                    const PropertiesMap&revProps=PropertiesMap());
 
     /**
      * Merge changes from two paths into a new local path.
@@ -477,7 +477,7 @@ namespace svn
            bool dry_run=false,
            bool record_only=false,
            const StringArray&merge_options=StringArray()
-          ) throw (ClientException);
+          );
 
     virtual void
     merge_peg(const Path&src,
@@ -490,7 +490,7 @@ namespace svn
                       bool force=false,
                       bool record_only=false,
                       const StringArray&merge_options=StringArray()
-                     ) throw (ClientException);
+                     );
 
     virtual void
     merge_peg(const Path&src,
@@ -502,7 +502,7 @@ namespace svn
               bool dry_run,
               bool force,
               const StringArray&merge_options
-            ) throw (ClientException);
+            );
 
     /**
      * Retrieve information for the given path
@@ -522,7 +522,7 @@ namespace svn
          const Revision & rev,
          const Revision & peg_revision=svn_opt_revision_unspecified,
          const StringArray&changelists=StringArray()
-        ) throw (ClientException);
+        );
     /**
      * Retrieve log information for the given path
      * Loads the log messages result set. The first
@@ -549,7 +549,7 @@ namespace svn
          bool strictNodeHistory=true,int limit=0,
          bool include_merged_revisions = false,
          const StringArray&revprops=StringArray()
-        ) throw (ClientException);
+        );
     /**
      * Retrieve log information for the given path
      * Loads the log messages result set. Result will stored
@@ -577,7 +577,7 @@ namespace svn
          bool strictNodeHistory,int limit,
          bool include_merged_revisions = false,
          const StringArray&revprops=StringArray()
-        ) throw (ClientException);
+        );
 
    /**
      * Produce diff output which describes the delta between
@@ -610,7 +610,7 @@ namespace svn
                 const StringArray&extra,
                 const StringArray&changelists
                      )
-            throw (ClientException);
+           ;
 
     /**
      * Same as other diff but extra options and changelists always set to empty list.
@@ -620,7 +620,7 @@ namespace svn
                 const Revision & revision1, const Revision & revision2, const Revision& peg_revision,
                 Depth depth, bool ignoreAncestry,
                 bool noDiffDeleted,bool ignore_contenttype)
-            throw (ClientException);
+           ;
 
     /**
      * Produce diff output which describes the delta between
@@ -654,7 +654,7 @@ namespace svn
                 const StringArray&extra,
                 const StringArray&changelists
                  )
-            throw (ClientException);
+           ;
 
     /**
      * Same as other diff but extra options always set to empty list.
@@ -664,7 +664,7 @@ namespace svn
                 const Revision & revision1, const Revision & revision2,
                 Depth depth, bool ignoreAncestry,
                 bool noDiffDeleted,bool ignore_contenttype)
-            throw (ClientException);
+           ;
 
     /**
      * lists entries in @a pathOrUrl no matter whether local or
@@ -682,7 +682,7 @@ namespace svn
     list (const Path& pathOrUrl,
           const Revision& revision,
           const Revision& peg,
-          svn::Depth depth,bool retrieve_locks) throw (ClientException);
+          svn::Depth depth,bool retrieve_locks);
 
     /**
      * lists properties in @a path no matter whether local or
@@ -830,7 +830,7 @@ namespace svn
    virtual void
    lock (const Targets & targets,
         const TQString& message,
-        bool steal_lock) throw (ClientException);
+        bool steal_lock);
     /**
      * unlock files in repository or working copy
      * @param targets items to unlock
@@ -838,7 +838,7 @@ namespace svn
      */
     virtual void
     unlock (const Targets&targets,
-            bool break_lock) throw (ClientException);
+            bool break_lock);
 
     virtual void
     url2Revision(const TQString&revstring,
@@ -875,12 +875,12 @@ namespace svn
     list_simple(const Path& pathOrUrl,
           const Revision& revision,
           const Revision& peg,
-          bool recurse) throw (ClientException);
+          bool recurse);
     DirEntries
     list_locks(const Path& pathOrUrl,
           const Revision& revision,
           const Revision& peg,
-          bool recurse) throw (ClientException);
+          bool recurse);
 
     svn_error_t * internal_cat(const Path & path,
                 const Revision & revision,
