@@ -1,5 +1,5 @@
 /*
- * Port for usage with qt-framework and development for tdesvn
+ * Port for usage with tqt-framework and development for tdesvn
  * (C) 2005-2007 by Rajko Albrecht
  * http://tdesvn.alwins-world.de
  */
@@ -36,10 +36,10 @@
 #include "apr_strings.h"
 
 // svncpp
-#include "svnqt/targets.hpp"
-#include "svnqt/path.hpp"
-#include "svnqt/pool.hpp"
-#include "svnqt/svnqt_defines.hpp"
+#include "svnqt/targets.h"
+#include "svnqt/path.h"
+#include "svnqt/pool.h"
+#include "svnqt/svnqt_defines.h"
 
 #include <tqstringlist.h>
 
