@@ -95,12 +95,12 @@ void tdesvnPart::init( TQWidget *parentWidget, const char *widgetName,bool full)
 #else
     setXMLFile("tdesvn_part.rc");
 #endif
-    connect(m_view,TQT_SIGNAL(sigShowPopup(const TQString&,TQWidget**)),this,TQT_SLOT(slotDispPopup(const TQString&,TQWidget**)));
-    connect(m_view,TQT_SIGNAL(sigSwitchUrl(const KURL&)),this,TQT_SLOT(openURL(const KURL&)));
-    connect(this,TQT_SIGNAL(refreshTree()),m_view,TQT_SLOT(refreshCurrentTree()));
-    connect(m_view,TQT_SIGNAL(setWindowCaption(const TQString&)),this,TQT_SIGNAL(setWindowCaption(const TQString&)));
-    connect(m_view,TQT_SIGNAL(sigUrlChanged( const TQString&)),this,TQT_SLOT(slotUrlChanged(const TQString&)));
-    connect(this,TQT_SIGNAL(settingsChanged()),widget(),TQT_SLOT(slotSettingsChanged()));
+    connect(m_view,TQ_SIGNAL(sigShowPopup(const TQString&,TQWidget**)),this,TQ_SLOT(slotDispPopup(const TQString&,TQWidget**)));
+    connect(m_view,TQ_SIGNAL(sigSwitchUrl(const KURL&)),this,TQ_SLOT(openURL(const KURL&)));
+    connect(this,TQ_SIGNAL(refreshTree()),m_view,TQ_SLOT(refreshCurrentTree()));
+    connect(m_view,TQ_SIGNAL(setWindowCaption(const TQString&)),this,TQ_SIGNAL(setWindowCaption(const TQString&)));
+    connect(m_view,TQ_SIGNAL(sigUrlChanged( const TQString&)),this,TQ_SLOT(slotUrlChanged(const TQString&)));
+    connect(this,TQ_SIGNAL(settingsChanged()),widget(),TQ_SLOT(slotSettingsChanged()));
 
     m_browserExt->setPropertiesActionEnabled(false);
 }
@@ -181,37 +181,37 @@ void tdesvnPart::setupActions()
     toggletemp = new TDEToggleAction(i18n("Logs follow node changes"),TDEShortcut(),
             actionCollection(),"toggle_log_follows");
     toggletemp->setChecked(Kdesvnsettings::log_follows_nodes());
-    connect(toggletemp,TQT_SIGNAL(toggled(bool)),this,TQT_SLOT(slotLogFollowNodes(bool)));
+    connect(toggletemp,TQ_SIGNAL(toggled(bool)),this,TQ_SLOT(slotLogFollowNodes(bool)));
 
     toggletemp = new TDEToggleAction(i18n("Display ignored files"),TDEShortcut(),
             actionCollection(),"toggle_ignored_files");
     toggletemp->setChecked(Kdesvnsettings::display_ignored_files());
-    connect(toggletemp,TQT_SIGNAL(toggled(bool)),this,TQT_SLOT(slotDisplayIgnored(bool)));
+    connect(toggletemp,TQ_SIGNAL(toggled(bool)),this,TQ_SLOT(slotDisplayIgnored(bool)));
 
 
     toggletemp = new TDEToggleAction(i18n("Display unknown files"),TDEShortcut(),
             actionCollection(),"toggle_unknown_files");
     toggletemp->setChecked(Kdesvnsettings::display_unknown_files());
-    connect(toggletemp,TQT_SIGNAL(toggled(bool)),this,TQT_SLOT(slotDisplayUnkown(bool)));
+    connect(toggletemp,TQ_SIGNAL(toggled(bool)),this,TQ_SLOT(slotDisplayUnkown(bool)));
 
     toggletemp = new TDEToggleAction(i18n("Hide unchanged files"),TDEShortcut(),
                                    actionCollection(),"toggle_hide_unchanged_files");
     toggletemp->setChecked(Kdesvnsettings::hide_unchanged_files());
-    connect(toggletemp,TQT_SIGNAL(toggled(bool)),this,TQT_SLOT(slotHideUnchanged(bool)));
+    connect(toggletemp,TQ_SIGNAL(toggled(bool)),this,TQ_SLOT(slotHideUnchanged(bool)));
 
     toggletemp = new TDEToggleAction(i18n("Work online"),TDEShortcut(),
                                    actionCollection(),"toggle_network");
     toggletemp->setChecked(Kdesvnsettings::network_on());
-    connect(toggletemp,TQT_SIGNAL(toggled(bool)),this,TQT_SLOT(slotEnableNetwork(bool)));
+    connect(toggletemp,TQ_SIGNAL(toggled(bool)),this,TQ_SLOT(slotEnableNetwork(bool)));
 
     kdDebug()<<"Appname = " << (TQString)kapp->instanceName() << endl;
 
-    TDEAction * t = KStdAction::preferences(this, TQT_SLOT(slotShowSettings()), actionCollection(),"tdesvnpart_pref");
+    TDEAction * t = KStdAction::preferences(this, TQ_SLOT(slotShowSettings()), actionCollection(),"tdesvnpart_pref");
     t->setText(i18n("&Configure %1...").arg("Kdesvn"));
     if (TQString(kapp->instanceName())!=TQString("tdesvn")) {
-        (void)new TDEAction(i18n("&About tdesvn part"), "tdesvn", 0, this, TQT_SLOT(showAboutApplication()), actionCollection(), "help_about_tdesvnpart");
-        (void)new TDEAction(i18n("Tdesvn &Handbook"), "help", 0, this, TQT_SLOT(appHelpActivated()), actionCollection(), "help_tdesvn");
-        (void)new TDEAction(i18n("Send Bugreport for tdesvn"), 0, 0, this, TQT_SLOT(reportBug()), actionCollection(), "report_bug");
+        (void)new TDEAction(i18n("&About tdesvn part"), "tdesvn", 0, this, TQ_SLOT(showAboutApplication()), actionCollection(), "help_about_tdesvnpart");
+        (void)new TDEAction(i18n("Tdesvn &Handbook"), "help", 0, this, TQ_SLOT(appHelpActivated()), actionCollection(), "help_tdesvn");
+        (void)new TDEAction(i18n("Send Bugreport for tdesvn"), 0, 0, this, TQ_SLOT(reportBug()), actionCollection(), "report_bug");
     }
     actionCollection()->setHighlightingEnabled(true);
 }
@@ -364,7 +364,7 @@ void tdesvnPart::slotShowSettings()
     dialog->addPage(new CmdExecSettings_impl(0,"cmdexec_items"),
         "TDEIO/"+i18n("Commandline"),"terminal",i18n("Settings for commandline and TDEIO execution"),true);
 
-    connect(dialog,TQT_SIGNAL(settingsChanged()),this,TQT_SLOT(slotSettingsChanged()));
+    connect(dialog,TQ_SIGNAL(settingsChanged()),this,TQ_SLOT(slotSettingsChanged()));
     dialog->show();
 }
 
